@@ -33,15 +33,16 @@ class Dataset:
             raise InvalidDatasetError(
                 "The 'dataset' column is required to exist in the csv."
             )
+        if len(set(self.data["dataset"])) > 1:
+            raise InvalidDatasetError("The dataset field contains multiple values.")
 
     def validate_dataset(self, metadata_table):
         pa_columns = {}
-        data_for_validation = self.data.copy()
         # Validating the dataset has proper values, according to the data model.
 
         # There is a need to construct a DataFrameSchema with all the constraints that the metadata is imposing
         # For each column a pandera Column is created that will contain the constraints for the specific column
-        for column in data_for_validation.columns:
+        for column in self.data.columns:
             if column not in metadata_table:
                 raise InvalidDatasetError(
                     f"The column: '{column}' does not exist in the metadata"
@@ -51,20 +52,6 @@ class Dataset:
             checks = self._get_pa_checks(metadata_column_dict)
             cde_sql_type = metadata_column_dict["sql_type"]
             pa_type = self._pa_type_from_sql_type(cde_sql_type)
-            # A pandas dataframe it is not possible for a column of integers to contain Nan values.
-            # It is automatically converted to float.
-            # The workaround is to replace the column's Nan values with valid integers.
-            # This change is only for the validation.
-            # This will not affect the dataframe that will be imported in the database.
-            if cde_sql_type == "int":
-                valid_int = 0
-                if "min" in metadata_column_dict:
-                    valid_int = metadata_column_dict["min"]
-                elif "max" in metadata_column_dict:
-                    valid_int = metadata_column_dict["max"]
-                data_for_validation[column] = data_for_validation[column].fillna(
-                    valid_int
-                )
             pa_columns[column] = pa.Column(dtype=pa_type, checks=checks, nullable=True)
 
         schema = pa.DataFrameSchema(
@@ -73,14 +60,16 @@ class Dataset:
         )
 
         try:
-            schema(data_for_validation)
+            schema(self.data)
         except pa.errors.SchemaError as exc:
             raise InvalidDatasetError(
                 f"An error occurred while validating the dataset: '{self._name}' and column: '{exc.schema.name}'\n{exc.failure_cases}"
             )
 
     def _pa_type_from_sql_type(self, sql_type):
-        return {"text": pa.String, "int": pa.Int, "real": pa.Float}.get(sql_type)
+        return {"text": pa.String, "int": pd.Int64Dtype(), "real": pa.Float}.get(
+            sql_type
+        )
 
     def to_dict(self):
         return self._data.to_dict("records")
